from Plugins.Plugin import PluginDescriptor
from ServiceReference import ServiceReference

from Screens.Screen import Screen
from Screens.InputBox import InputBox
from Screens.MessageBox import MessageBox
from Components.ServicePosition import ServicePositionGauge
from Components.ActionMap import HelpableActionMap
from Components.MenuList import MenuList
from Components.MultiContent import MultiContentEntryText
from Components.ServiceEventTracker import ServiceEventTracker
from Components.ActionMap import ActionMap
from Components.Input import Input
from Screens.InfoBarGenerics import InfoBarSeek, InfoBarCueSheetSupport
from Components.GUIComponent import GUIComponent
from enigma import eListboxPythonMultiContent, eListbox, gFont, iPlayableService, RT_HALIGN_RIGHT, eServiceCenter, eServiceReference, iServiceInformation
from Screens.FixedMenu import FixedMenu
from Tools.Directories import *
import os
from time import *
import time
import datetime


def main(session, **kwargs):
	session.open(TimeshiftSave)

def Plugins(**kwargs):
 	return PluginDescriptor(name="Timeshift Save", description=_("Timeshift Save to Recording Plugin"), where = PluginDescriptor.WHERE_PLUGINMENU, icon="timeshiftsave.png", fnc=main)


class TimeshiftSave(Screen):
    skin = """
        <screen position="100,100" size="500,200" title="Timeshift Save Menu" >
            <widget name="menu" position="10,10" size="490,190" scrollbarMode="showOnDemand" />
        </screen>"""
        
    def __init__(self, session, args = 0):
        self.skin = TimeshiftSave.skin
        self.session = session
        Screen.__init__(self, session)
        self.menu = args
        list = []
	service = session.nav.getCurrentService()
	self.service = service
        numberofts=0
        for filename in os.listdir("/media/hdd"): 
           if filename.startswith("timeshift.") is True:
              numberofts = numberofts +1
        if numberofts < 1: 
           list.append((_("no timeshifts found"), "notimeshift"))        
        elif numberofts > 1: 
           list.append((_("clean first multiple timeshifts"), "cleantimeshift"))        
        else:
           list.append((_("backup current timeshift"), "backuptimeshift"))
        list.append((_("about"), "about"))        
        self["menu"] = MenuList(list)
        self["actions"] = ActionMap(["WizardActions", "DirectionActions"],{"ok": self.go,"back": self.close,}, -1)
        
    def go(self):
        returnValue = self["menu"].l.getCurrentSelection()[1]
        if returnValue is not None:
           if returnValue is "notimeshift":
              self.session.open(MessageBox,_("Start timeshift first, or nothing to save !"), MessageBox.TYPE_WARNING)
           elif returnValue is "cleantimeshift":
              for filename in os.listdir("/media/hdd"): 
                 if filename.startswith("timeshift.") is True:
                    # dirtycheck if file is still growing
                    size1 = os.path.getsize("/media/hdd/%s" % filename)
                    # dirty hack to spend some time and see if file is growing
                    os.system("wall checking timeshift")
                    size2 = os.path.getsize("/media/hdd/%s" % filename)
                    if size1 == size2:
                       os.system("rm /media/hdd/%s" % filename)
              self.session.open(MessageBox,_("Old timeshift cleaned !"), MessageBox.TYPE_INFO)
           elif returnValue is "backuptimeshift":
              BackupTimeshift(self.session)
           elif returnValue is "about":
              self.session.open(MessageBox,_("Timeshift Save Enigma2 Plugin\nVersion 4.0 by gutemine"), MessageBox.TYPE_INFO)
        

class BackupTimeshift(Screen):
    def __init__(self, session):

        self.session = session
        Screen.__init__(self, session)
   	self.service = self.session.nav.getCurrentlyPlayingServiceReference()
	serviceHandler = eServiceCenter.getInstance()
	info = serviceHandler.info(self.service)
	self.oldname = info and info.getName(self.service) or _("this recording")
	self.station = self.oldname
        self.begin = time.time()
        timezone = datetime.datetime.utcnow()
        delta = (self.begin - time.mktime(timezone.timetuple())+10)/3600 
        self.begin_string = strftime("%Y%m%d %H%M",gmtime(self.begin+3600*int(delta)))
        
        fullnameunchecked = "%s - %s - %s" % (self.begin_string,self.station,self.oldname)
        # use enigma2 filename routine - thank's ritzMo !
        fullname=getRecordingFilename(fullnameunchecked)
        # quick & dirty header & trailer remove 
        fullname=fullname.replace("_001","",1)
        fullname=fullname.replace("/hdd/movie/","",1)
        print "saving timeshift to %s" % fullname
        self.oldfullname=fullname.rstrip()
        self.session.openWithCallback(self.processingBackup,InputBox, title=_("Enter name for saving current Timeshift"), text="%s Timeshift Backup                                " % (self.oldname), maxSize=50, type=Input.TEXT)

    def processingBackup(self,targetname):
        if targetname is None:
            self.skipTimeshiftBackup("Timeshift save name is NONE, skipping save")
        else:
            self.newname = targetname.lstrip().rstrip()
            fullnameunchecked = "%s - %s - %s" % (self.begin_string,self.station,self.newname)
            # use enigma2 filename routine - thank's ritzMo !
            fullname=getRecordingFilename(fullnameunchecked)
            # quick & dirty header & trailer remove 
            fullname=fullname.replace("_001","",1)
            fullname=fullname.replace("/hdd/movie/","",1)
            print "checking for new %s files" % fullname
            self.newfullname=fullname.rstrip()
            if os.path.exists("/media/hdd/movie/%s.ts.meta" % self.newfullname) is True:
               self.skipTimeshiftBackup("%s.ts.meta already exists" % self.newfullname)
            elif os.path.exists("/media/hdd/movie/%s.ts" % self.newfullname) is True:
               self.skipTimeshiftBackup("%s.ts.ap already exists" % self.newfullname)
            else:
               self.session.openWithCallback(self.TimeshiftBackup,MessageBox,_("Sure to save current Timeshift to %s ?" % (self.newname)), MessageBox.TYPE_YESNO)

    def TimeshiftBackup(self,answer):
        if answer is None:
            self.skipTimeshiftBackup("answer is None")
        if answer is False:
            self.skipTimeshiftBackup("you were not confirming")
        else:
            print "Saving Timeshift to %s.ts" %(self.newfullname)

            for filename in os.listdir("/media/hdd"): 
               if filename.startswith("timeshift.") is True:
                  os.link("/media/hdd/%s" % filename, "/media/hdd/movie/%s.ts" % self.newfullname)
            metafile = open("/media/hdd/movie/%s.ts.meta" % self.newfullname, "w")
            serviceref = self.session.nav.getCurrentlyPlayingServiceReference().toString()
            metafile.write("%s\n%s\nsaved Timeshift recording\n%s\n" % (serviceref,self.newname,int(self.begin)))
            metafile.close()
            self.session.open(MessageBox,_("Timeshift save completed !"), MessageBox.TYPE_INFO)
            
            
    def skipTimeshiftBackup(self,reason):
        self.session.open(MessageBox,_("Saving Timeshift was canceled, because %s" % reason), MessageBox.TYPE_WARNING)
        
        
